zglm: Run a glm model in a pipe (see zlm)
Description
Run a glm model in a pipe (see zlm)
Usage
zglm(data, formula, family = gaussian, ...)
Arguments
data
A data.frame containing the model data.
formula
The formula to be fitted.
family
The family function to use for fitting the model.
...
Other arguments to be passed to the glm function.